@@ -122,8 +122,8 @@ test_that("strange name re-casing does not break things", {
   deploy2 <- deploy(test_conn_1, bnd, testname)
 
   testname2 <- "test_Test"
-  deployA <- deploy(test_conn_1, bnd, testname2)
-  deployB <- deploy(test_conn_1, bnd, testname2)
+  deploy(test_conn_1, bnd, testname2)
+  deploy(test_conn_1, bnd, testname2)
 })
 
 test_that(".pre_deploy hook works", {
@@ -247,6 +247,10 @@ test_that("get_image returns NA if no image", {
 test_that("set_image_url works", {
   scoped_experimental_silence()
 
+  # This test fails with the 1.8.8.2 image. The failure is to do with
+  # downloading the favicon, used in the test as the remote image.
+  skip_if_connect_older_than(cont1_content$connect, "2021.09.0")
+
   res <- set_image_url(cont1_content, glue::glue("{cont1_content$get_connect()$server}/connect/__favicon__"))
 
   expect_true(validate_R6_class(res, "Content"))
@@ -444,3 +448,86 @@ test_that("deployment timestamps respect timezone", {
   # (really protecting against being off by hours b/c of timezone differences)
   expect_lt(Sys.time() - all_usage$time, lubridate::make_difftime(60, "seconds"))
 })
+
+# thumbnail ---------------------------------------------------
+
+test_that("set_thumbnail works with local images", {
+  scoped_experimental_silence()
+  img_path <- rprojroot::find_package_root_file("tests/testthat/examples/logo.png")
+
+  res <- set_thumbnail(cont1_content, img_path)
+
+  expect_true(validate_R6_class(res, "Content"))
+})
+
+test_that("get_thumbnail works", {
+  scoped_experimental_silence()
+  img_path <- rprojroot::find_package_root_file("tests/testthat/examples/logo.png")
+
+  tmp_img <- fs::file_temp(pattern = "img", ext = ".png")
+  get_thumbnail(cont1_content, tmp_img)
+
+  expect_identical(
+    readBin(img_path, "raw"),
+    readBin(tmp_img, "raw")
+  )
+
+  # works again (i.e. does not append data)
+  get_thumbnail(cont1_content, tmp_img)
+  expect_identical(
+    readBin(img_path, "raw"),
+    readBin(tmp_img, "raw")
+  )
+
+  # works with no path
+  auto_path <- get_thumbnail(cont1_content)
+  expect_identical(
+    readBin(img_path, "raw"),
+    readBin(auto_path, "raw")
+  )
+  expect_identical(fs::path_ext(auto_path), "png")
+})
+
+test_that("has_thumbnail works with an image", {
+  scoped_experimental_silence()
+
+  expect_true(has_thumbnail(cont1_content))
+})
+
+test_that("delete_thumbnail works", {
+  scoped_experimental_silence()
+
+  expect_true(validate_R6_class(delete_thumbnail(cont1_content), "Content"))
+  expect_false(has_thumbnail(cont1_content))
+
+  # works again - i.e. if no image available
+  expect_true(validate_R6_class(delete_thumbnail(cont1_content), "Content"))
+})
+
+test_that("has_thumbnail works with no image", {
+  scoped_experimental_silence()
+
+  expect_false(has_thumbnail(cont1_content))
+})
+
+test_that("get_thumbnail returns NA if no image", {
+  scoped_experimental_silence()
+
+  tmp_img <- fs::file_temp(pattern = "img", ext = ".png")
+  response <- get_thumbnail(cont1_content, tmp_img)
+
+  expect_false(identical(tmp_img, response))
+  expect_true(is.na(response))
+})
+
+test_that("set_thumbnail works with remote paths", {
+  scoped_experimental_silence()
+
+  # This test fails with the 1.8.8.2 image. The failure is to do with
+  # downloading the favicon, used in the test as the remote image.
+  skip_if_connect_older_than(cont1_content$connect, "2021.09.0")
+
+  res <- set_thumbnail(cont1_content, glue::glue("{cont1_content$get_connect()$server}/connect/__favicon__"))
+
+  expect_true(validate_R6_class(res, "Content"))
+})
